@@ -5,12 +5,15 @@ to represent your data source and your evaluated model respectively.
 
 Logging is available for this framework, using logger `propinfer`.
 
+Version 1.2.0
+
 (c) [EPFL](https://epfl.ch/) [Data Science Lab (dlab)](https://dlab.epfl.ch/) 2022"""
 
 import logging
 
 from propinfer.experiment import Experiment
-from propinfer.generator import Generator, GaussianGenerator, IndependentPropertyGenerator, SubsamplingGenerator
+from propinfer.generator import Generator, GaussianGenerator, IndependentPropertyGenerator, ProbitGenerator, \
+    NonlinearGenerator, SubsamplingGenerator
 from propinfer.model import Model, LogReg, MLP
 
 logging.getLogger('propinfer').addHandler(logging.NullHandler())
